@@ -20,6 +20,7 @@ from .resourceCategory import (getResourceCategory, getResourceCategorys,
 from .resourceLocation import (getResourceLocation, getResourceLocations,
                                newResourceLocation)
 from .collection import newCollection
+from .device import getDevice, getDevices, newDevice
 
 
 def newUser(first_name, last_name, email, password,
@@ -335,6 +336,28 @@ class User(Entity):
         """
         return getFile(self, file_id)
 
+    def getDevice(self, device_id):
+        """
+        Retrieve a specific Labstep Device.
+
+        Parameters
+        ----------
+        device_id (int)
+            The id of the Device to retrieve.
+
+        Returns
+        -------
+        :class:`~labstep.device.Device`
+            An object representing a Device on Labstep.
+
+        Example
+        -------
+        ::
+
+            entity = user.getDevice(17000)
+        """
+        return getDevice(self, device_id)
+
     # getMany()
     def getExperiments(self, count=100, search_query=None,
                        created_at_from=None, created_at_to=None, tag_id=None,
@@ -669,6 +692,35 @@ class User(Entity):
                         file_type=file_type,
                         extraParams=extraParams)
 
+    def getDevices(self, count=100, search_query=None,
+                   extraParams={}):
+        """
+        Retrieve a list of a User's Devices
+        across all Workspaces on Labstep,
+        which can be filtered using the parameters:
+
+        Parameters
+        ----------
+        count (int)
+            The number of Devices to retrieve.
+        search_query (str)
+            Search for Devices by name / metadata fields.
+
+        Returns
+        -------
+        List[:class:`~labstep.device.Device`]
+            A list of Labstep Devices.
+
+        Example
+        -------
+        ::
+
+            entity = user.getDevices(search_query='microscope')
+        """
+        return getDevices(self,
+                          count=count,
+                          search_query=search_query,
+                          extraParams=extraParams)
     # newEntity()
 
     def newExperiment(self, name, entry=None, extraParams={}):
@@ -902,6 +954,28 @@ class User(Entity):
         """
         return newCollection(self, name=name, type=type)
 
+    def newDevice(self, name, extraParams={}):
+        """
+        Create a new Labstep Device.
+
+        Parameters
+        ----------
+        name (str)
+            Give your Device a name.
+
+        Returns
+        -------
+        :class:`~labstep.device.Device`
+            An object representing a Device on Labstep.
+
+        Example
+        -------
+        ::
+
+            entity = user.newDevice(name='Microscope A')
+        """
+        return newDevice(self, name, extraParams=extraParams)
+
     def acceptSharelink(self, token):
         """
         Accept a sharelink
